import React, { createContext, useContext } from "react";
import { message } from "antd";

interface MessageContextType {
  info: (content: string) => void;
  success: (content: string) => void;
  error: (content: string) => void;
  warning: (content: string) => void;
}

const MessageContext = createContext<MessageContextType | null>(null);

export const MessageProvider: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  const [messageApi, contextHolder] = message.useMessage();

  const info = (content: string) => {
    messageApi.info(content);
  };

  const success = (content: string) => {
    messageApi.success(content);
  };

  const error = (content: string) => {
    messageApi.error(content);
  };

  const warning = (content: string) => {
    messageApi.warning(content);
  };

  return (
    <MessageContext.Provider value={{ info, success, error, warning }}>
      {contextHolder}
      {children}
    </MessageContext.Provider>
  );
};

export const useMessage = () => {
  const context = useContext(MessageContext);

  if (!context) {
    throw new Error("useMessage must be used within a MessageProvider");
  }

  return context;
};
