import { useDispatch, useSelector } from "react-redux";
import { useGetUserQuery } from "./userProfile";
import { addUserToCache, cachedUsers } from "core/reducers/appSlice";
import { CachedUser } from "core/types/userProfile";
import { useEffect } from "react";

export function useCachedUser(userId: string) {
  const dispatch = useDispatch();
  const cachedUser = useSelector(cachedUsers)[userId] as CachedUser;

  const {
    data: user,
    error,
    isLoading,
  } = useGetUserQuery(userId, {
    skip: !!cachedUser, // Skip the query if the user is already cached
  });

  useEffect(() => {
    if (user) {
      dispatch(addUserToCache(user));
    }
  }, [user]);

  return {
    user: cachedUser || user,
    error,
    isLoading,
  };
}
