import { createSlice } from "@reduxjs/toolkit";
import { LessonContent } from "core/types/lesson";

export const lessonPageSlice = createSlice({
  name: "lessonPage",
  initialState: {
    currentLessonId: "",
    lessonContents: [] as LessonContent[],
  },
  reducers: {
    setLessonPageCurrentLessonId: (state, action) => {
      state.currentLessonId = action.payload;
    },
    setLessonPageContents: (state, action) => {
      state.lessonContents = action.payload;
    },
    addLessonPageContent: (state, action) => {
      state.lessonContents.push(action.payload);
    },
    deleteLessonPageContent: (state, action) => {
      state.lessonContents = state.lessonContents.filter(
        (content) => content.Id !== action.payload
      );
    },
    updateLessonPageContent: (state, action) => {
      const index = state.lessonContents.findIndex(
        (content) => content.Id === action.payload.id
      );

      if (index !== -1) {
        state.lessonContents[index].Data = action.payload.data;
      }
    },
    updateLessonPageContentPosition: (state, action) => {
      // change only by contentId and new position
      const content = state.lessonContents.find(
        (content) => content.Id === action.payload.contentId
      );

      if (content) {
        const index = state.lessonContents.indexOf(content);
        state.lessonContents.splice(index, 1);
        state.lessonContents.splice(action.payload.position - 1, 0, content);
      }
    },
  },
  selectors: {
    lessonPageCurrentLessonId: (state) => state.currentLessonId,
    lessonPageContents: (state) => state.lessonContents,
  },
});

export const {
  setLessonPageCurrentLessonId,
  setLessonPageContents,
  addLessonPageContent,
  deleteLessonPageContent,
  updateLessonPageContent,
  updateLessonPageContentPosition,
} = lessonPageSlice.actions;

export const { lessonPageCurrentLessonId, lessonPageContents } =
  lessonPageSlice.selectors;
