import { defaultAnimateLayoutChanges, useSortable } from "@dnd-kit/sortable";
import { CSS } from "@dnd-kit/utilities";
import {
  HolderOutlined,
  DeleteOutlined,
  CameraOutlined,
  FolderOpenOutlined,
} from "@ant-design/icons";
import { Flex } from "antd";
import {
  currentLessonId,
  deleteLessonContent,
  updateLessonContent,
} from "./lessonPageEditorSlice";
import { useDispatch, useSelector } from "react-redux";
import { getComponentByType } from "../components";
import { LessonContent } from "core/types/lesson";
import "./styles.module.css";
import { Converter } from "../converter";
import { useDeleteLessonContentMutation } from "core/services/lessons";

/*
const animateLayoutChanges = (args: any) =>
  args.isSorting || args.wasDragging ? defaultAnimateLayoutChanges(args) : true;
*/
const SortableEditorItem = (props: { item: LessonContent }) => {
  const lnContent = props.item;
  const {
    attributes,
    listeners,
    setNodeRef,
    transform,
    transition,
    isDragging,
  } = useSortable({ id: lnContent.Id });

  const dispatch = useDispatch();

  const component = getComponentByType(lnContent.Type);

  const [reqDeleteLessonContent] = useDeleteLessonContentMutation();
  const currentLnId = useSelector(currentLessonId);

  if (!component) {
    return null;
  }

  return (
    <div
      style={{
        transform: CSS.Translate.toString(transform),
        transition,
      }}
      ref={setNodeRef}
      {...attributes}
    >
      <Flex key={lnContent.Id}>
        <Flex>
          <HolderOutlined
            style={{
              paddingLeft: 8,
              paddingRight: 8,
              touchAction: "none",
              cursor: "grab",
              opacity: isDragging ? 0 : 1,
            }}
            {...listeners}
          />
        </Flex>
        <Flex
          style={{
            overflow: "hidden",
            width: "100%",
            transition: "",
            boxShadow: isDragging ? "rgba(0, 0, 0, 0.08) 0px 5px 15px" : "",
          }}
        >
          <Converter
            mode="edititable"
            lessonContent={lnContent}
            onEdit={(data) => {
              console.log("edit", lnContent.Id, data);

              dispatch(
                updateLessonContent({
                  id: lnContent.Id,
                  data: data,
                })
              );
            }}
          />
        </Flex>

        <Flex vertical justify="center" style={{ paddingLeft: 12 }}>
          <div className="EditorActionIcon">
            <DeleteOutlined
              className="EditorActionIcon"
              onClick={() => {
                console.log("delete", lnContent.Id);
                dispatch(deleteLessonContent(lnContent.Id));

                try {
                  reqDeleteLessonContent({
                    lessonId: currentLnId,
                    contentId: lnContent.Id,
                  });
                } catch (err) {
                  console.error(err);
                }
              }}
            />
          </div>
        </Flex>
      </Flex>
    </div>
  );
};

/*
 {component.uploadImage ? (
    <div className="EditorActionIcon">
        <CameraOutlined />
    </div>
) : null}
{component.uploadFileTypes ? (
    <div className="EditorActionIcon">
        <FolderOpenOutlined className="EditorActionIcon" />{' '}
    </div>
) : null}
*/

export default SortableEditorItem;
