import { createSlice } from "@reduxjs/toolkit";
import { LessonContent, LessonState } from "core/types/lesson";

interface AddLessonContentAction {
  type: string;
  payload: LessonContent;
}

export const lessonPageEditorSlice = createSlice({
  name: "lessonPageEditor",
  initialState: {
    editorActive: false,
    currentLessonId: "", // required in sideMenu because has no access to useParams
    lessonThumbnail: {
      title: "Test",
      url: "",
    },
    lessonContents: [] as LessonContent[],
    lessonState: LessonState.Draft,
  },
  reducers: {
    setEditorActive: (state, action) => {
      state.editorActive = action.payload;
    },
    setCurrentLessonId: (state, action) => {
      state.currentLessonId = action.payload;
    },
    addLessonContent: (state, action: AddLessonContentAction) => {
      state.lessonContents.push(action.payload);
    },
    deleteLessonContent: (state, action) => {
      state.lessonContents = state.lessonContents.filter(
        (content) => content.Id !== action.payload
      );
    },
    setLessonContents: (state, action) => {
      state.lessonContents = action.payload;
    },
    updateLessonContent: (state, action) => {
      const index = state.lessonContents.findIndex(
        (content) => content.Id === action.payload.id
      );

      if (index !== -1) {
        state.lessonContents[index].Data = action.payload.data;
      }
    },
    setLessonThumbnailTitle: (state, action) => {
      state.lessonThumbnail.title = action.payload;
    },
    setLessonThumbnailUrl: (state, action) => {
      state.lessonThumbnail.url = action.payload;
    },
    onDragHandler: (state, action) => {
      state.lessonContents.splice(
        action.payload.newIndex,
        0,
        state.lessonContents.splice(action.payload.oldIndex, 1)[0]
      );
    },
    setPageEditorLessonState: (state, action) => {
      state.lessonState = action.payload;
    },
    updateLessonContentPosition: (state, action) => {
      // change only by contentId and new position
      const content = state.lessonContents.find(
        (content) => content.Id === action.payload.contentId
      );

      if (content) {
        const index = state.lessonContents.indexOf(content);
        state.lessonContents.splice(index, 1);
        state.lessonContents.splice(action.payload.position - 1, 0, content);
      }
    },
  },
  selectors: {
    editorActive: (state) => state.editorActive,
    currentLessonId: (state) => state.currentLessonId,
    lessonContents: (state) => state.lessonContents,
    lessonThumbnail: (state) => state.lessonThumbnail,
    lessonState: (state) => state.lessonState,
  },
});

export const {
  setEditorActive,
  setCurrentLessonId,
  addLessonContent,
  deleteLessonContent,
  setLessonContents,
  updateLessonContent,
  setLessonThumbnailTitle,
  setLessonThumbnailUrl,
  onDragHandler,
  setPageEditorLessonState,
  updateLessonContentPosition,
} = lessonPageEditorSlice.actions;

export const {
  editorActive,
  currentLessonId,
  lessonContents,
  lessonThumbnail,
  lessonState,
} = lessonPageEditorSlice.selectors;
