import { createSlice } from "@reduxjs/toolkit";
import { LessonQuestion } from "core/types/lesson";

export const lessonQuestionsSlice = createSlice({
  name: "questions",
  initialState: {
    questions: [] as LessonQuestion[],
    likedQuestions: [] as string[],
  },
  reducers: {
    setQuestions: (state, action) => {
      state.questions = action.payload as LessonQuestion[];
    },
    addQuestion: (state, action) => {
      state.questions.push(action.payload as LessonQuestion);
    },
    setLikedQuestions: (state, action) => {
      state.likedQuestions = action.payload as string[];
    },
    addLikedQuestion: (state, action) => {
      state.likedQuestions.push(action.payload as string);
    },
    deleteLikedQuestion: (state, action) => {
      const questionId = action.payload as string;

      state.likedQuestions = state.likedQuestions.filter(
        (qId) => qId !== questionId
      );
    },
    countUpLikedQuestion: (state, action) => {
      const questionId = action.payload as string;

      const question = state.questions.find((q) => q.Id === questionId);

      if (question) {
        question.Likes++;
      }
    },
    countDownLikedQuestion: (state, action) => {
      const questionId = action.payload as string;

      const question = state.questions.find((q) => q.Id === questionId);

      if (question) {
        question.Likes--;
      }
    },
  },
  selectors: {
    questions: (state) => state.questions,
    likedQuestions: (state) => state.likedQuestions,
  },
});

export const {
  setQuestions,
  addQuestion,
  setLikedQuestions,
  addLikedQuestion,
  deleteLikedQuestion,
  countUpLikedQuestion,
  countDownLikedQuestion,
} = lessonQuestionsSlice.actions;

export const { questions, likedQuestions } = lessonQuestionsSlice.selectors;
