import { createSlice } from "@reduxjs/toolkit";
import { TeamMember } from "core/types/organization";

interface AddTeamMemberAction {
  type: string;
  payload: TeamMember;
}

export const teamSlice = createSlice({
  name: "team",
  initialState: {
    teamMembers: [] as TeamMember[],
  },
  reducers: {
    addTeamMember: (state, action: AddTeamMemberAction) => {
      state.teamMembers.push(action.payload);
    },
    setTeamMembers: (state, action) => {
      state.teamMembers = action.payload;
    },
    updateTeamMemberRole: (state, action) => {
      const member = state.teamMembers.find(
        (member) => member.Id === action.payload.MemberId
      );

      if (member) {
        member.RoleId = action.payload.RoleId;
      }
    },
    deleteTeamMember: (state, action) => {
      state.teamMembers = state.teamMembers.filter(
        (member) => member.Id !== action.payload
      );
    },
  },
  selectors: {
    teamMembers: (state) => state.teamMembers,
  },
});

export const {
  addTeamMember,
  setTeamMembers,
  updateTeamMemberRole,
  deleteTeamMember,
} = teamSlice.actions;

export const { teamMembers } = teamSlice.selectors;
