import ImgCrop, { ImgCropProps } from "antd-img-crop";
import Upload from "antd/es/upload/Upload";
import { getApiHeader } from "core/helper/api";
import { Constants } from "core/utils/utils";

export default function MyUpload({
  children,
  imgCropProps,
  accept = Constants.ACCEPTED_IMAGE_FILE_TYPES,
  maxCount = 1,
  showUploadList = false,
  headers = getApiHeader(),
  action,
  onChange,
  fileType = "image",
}: {
  children: React.ReactNode;
  imgCropProps?: ImgCropProps;
  accept?: string | string[];
  maxCount?: number;
  showUploadList?: boolean;
  headers?: any;
  action?: string;
  onChange?: (info: any) => void;
  fileType?: "image" | "video";
}) {
  const beforeUpload = (file: File) => {
    if (!accept.includes(file.type)) {
      console.error("File typ not allowed!");
      return false;
    }

    if (file.size > Constants.MAX_IMAGE_SIZE) {
      console.error("Image is to large!");
      return false;
    }

    return true;
  };

  const acceptFileTypes = Array.isArray(accept)
    ? accept.join(",")
    : (accept as string);

  if (fileType === "video") {
    return (
      <Upload
        accept={acceptFileTypes}
        maxCount={maxCount}
        showUploadList={showUploadList}
        headers={headers}
        action={`${Constants.API_ADDRESS}${action}`}
        onChange={(info) => {
          if (onChange) onChange(info);
        }}
        beforeUpload={beforeUpload}
      >
        {children}
      </Upload>
    );
  }

  return (
    <ImgCrop {...imgCropProps} rotationSlider>
      <Upload
        accept={acceptFileTypes}
        maxCount={maxCount}
        showUploadList={showUploadList}
        headers={headers}
        action={`${Constants.API_ADDRESS}${action}`}
        onChange={(info) => {
          if (onChange) onChange(info);
        }}
        beforeUpload={beforeUpload}
      >
        {children}
      </Upload>
    </ImgCrop>
  );
}
